@@ -1,6 +1,17 @@
+import jsonlines
+
+import attr
+from tqdm import tqdm
+
 from regipy.plugins.plugin import PLUGINS
 
 
+def dump_hive_to_json(registry_jhive, output_path, name_key_entry, verbose=False):
+    with jsonlines.open(output_path, mode='w') as writer:
+        for entry in tqdm(registry_jhive.recurse_subkeys(name_key_entry, as_json=True), disable=not verbose):
+            writer.write(attr.asdict(entry))
+
+
 def run_relevant_plugins(registry_hive, as_json=False, plugins=None):
     """
     Execute the relevant plugins on the hive
